/* Source Installer, Copyright (c) 2005,2006,2007 Claudio Fontana

 srccallback.h - simple callbacks

 This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.

 This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
     along with this program (look for the file called COPYING);
     if not, write to the Free Software Foundation, Inc.,
         51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

     You can contact the author (Claudio Fontana) by sending a mail
     to claudio@gnu.org
*/

#ifndef SRCINST_CALLBACK_H
#define SRCINST_CALLBACK_H

struct _callback_list {
    int count;
    struct _callback_node *first;
};

struct _callback_node {
    srcinst_callback callback;
    struct _callback_node *next;
};

void _init_callback_list(struct _callback_list *list);
void _add_callback_list(struct _callback_list *list,
			srcinst_callback callback);
void _remove_callback_list(struct _callback_list *list,
			   srcinst_callback callback);
void _fini_callback_list(struct _callback_list *list);

#endif				/* SRCINST_CALLBACK_H */
